You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by tr...@apache.org on 2005/06/20 15:33:05 UTC

svn commit: r191462 [1/2] - in /directory/apacheds/branches/db_refactor/core/src: main/java/org/apache/ldap/server/authz/ main/java/org/apache/ldap/server/exception/ main/java/org/apache/ldap/server/interceptor/ main/java/org/apache/ldap/server/invocat...

Author: trustin
Date: Mon Jun 20 06:33:00 2005
New Revision: 191462

URL: http://svn.apache.org/viewcvs?rev=191462&view=rev
Log:
Moved current PartitionStore classes to store.impl.btree; I'm going to make them only specific to BTree implementations for now to simplify API.

Added:
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DefaultOptimizer.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DefaultOptimizer.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DefaultSearchEngine.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DefaultSearchEngine.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DisjunctionEnumeration.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DisjunctionEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DupsEnumeration.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DupsEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/Enumerator.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/Enumerator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/Evaluator.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/Evaluator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/ExpressionEnumerator.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/ExpressionEnumerator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/ExpressionEvaluator.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/ExpressionEvaluator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/Index.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/Index.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/IndexAssertion.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/IndexAssertion.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/IndexAssertionEnumeration.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/IndexAssertionEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/IndexComparator.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/IndexComparator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/IndexEnumeration.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/IndexEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/IndexNotFoundException.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/IndexNotFoundException.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/IndexRecord.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/IndexRecord.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/KeyOnlyComparator.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/KeyOnlyComparator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/LeafEvaluator.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/LeafEvaluator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/MasterTable.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/MasterTable.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/NoDupsEnumeration.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/NoDupsEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/Optimizer.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/Optimizer.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/PartitionStore.java
      - copied, changed from r191459, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/PartitionStore.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/PartitionStoreSearchResult.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/PartitionStoreSearchResult.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/ResultFilteringEnumeration.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/ResultFilteringEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/ScopeEnumerator.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/ScopeEnumerator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/ScopeEvaluator.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/ScopeEvaluator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/SearchEngine.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/SearchEngine.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/SearchResultEnumeration.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/SearchResultEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/SearchResultFilter.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/SearchResultFilter.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/SubstringEnumerator.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/SubstringEnumerator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/SubstringEvaluator.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/SubstringEvaluator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/Table.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/Table.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/Tuple.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/Tuple.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/TupleBrowser.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/TupleBrowser.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/TupleComparator.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/TupleComparator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/TupleEnumeration.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/TupleEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/TupleRenderer.java
      - copied, changed from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/TupleRenderer.java
Removed:
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/BackingStore.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DefaultOptimizer.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DefaultSearchEngine.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DisjunctionEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DupsEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/Enumerator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/Evaluator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/ExpressionEnumerator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/ExpressionEvaluator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/Index.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/IndexAssertion.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/IndexAssertionEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/IndexComparator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/IndexEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/IndexNotFoundException.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/IndexRecord.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/KeyOnlyComparator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/LeafEvaluator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/MasterTable.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/NoDupsEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/Optimizer.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/PartitionStore.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/PartitionStoreSearchResult.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/ResultFilteringEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/ScopeEnumerator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/ScopeEvaluator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/SearchEngine.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/SearchResultEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/SearchResultFilter.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/SubstringEnumerator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/SubstringEvaluator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/Table.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/Tuple.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/TupleBrowser.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/TupleComparator.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/TupleEnumeration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/TupleRenderer.java
Modified:
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authz/AuthorizationService.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/exception/ExceptionService.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/interceptor/Interceptor.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Add.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Delete.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/EntryInvocation.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetMatchedDN.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetSuffix.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/HasEntry.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Invocation.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/IsSuffix.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/List.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ListSuffixes.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Lookup.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/LookupWithAttrIds.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Modify.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ModifyMany.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ModifyRN.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Move.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/MoveAndModifyRN.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Search.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/SubtreeInvocation.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/DefaultContextFactoryConfiguration.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/RootNexusProxy.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/SystemPartition.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/normalization/NormalizationService.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/operational/OperationalAttributeService.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/AbstractContextPartition.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ApplicationPartition.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ContextPartition.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/PartitionNexus.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/RootNexus.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/jdbm/JdbmIndex.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/jdbm/JdbmMasterTable.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/jdbm/JdbmPartitionStore.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/jdbm/JdbmTable.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/jdbm/JdbmTupleBrowser.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/gui/EntryNode.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/gui/IndexDialog.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/gui/MainFrame.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/gui/PartitionViewer.java
    directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/schema/SchemaService.java
    directory/apacheds/branches/db_refactor/core/src/test/org/apache/ldap/server/authz/AuthorizationServiceAsAdminTest.java
    directory/apacheds/branches/db_refactor/core/src/test/org/apache/ldap/server/authz/AuthorizationServiceAsNonAdminTest.java

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authz/AuthorizationService.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authz/AuthorizationService.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authz/AuthorizationService.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/authz/AuthorizationService.java Mon Jun 20 06:33:00 2005
@@ -44,15 +44,15 @@
 import org.apache.ldap.server.invocation.Search;
 import org.apache.ldap.server.jndi.ServerContext;
 import org.apache.ldap.server.jndi.SystemPartition;
-import org.apache.ldap.server.partition.BackingStore;
-import org.apache.ldap.server.partition.store.ResultFilteringEnumeration;
-import org.apache.ldap.server.partition.store.SearchResultFilter;
+import org.apache.ldap.server.partition.ContextPartition;
+import org.apache.ldap.server.partition.store.impl.btree.ResultFilteringEnumeration;
+import org.apache.ldap.server.partition.store.impl.btree.SearchResultFilter;
 import org.apache.ldap.server.schema.AttributeTypeRegistry;
 import org.apache.ldap.server.schema.ConcreteNameComponentNormalizer;
 
 
 /**
- * An {@link org.apache.ldap.server.interceptor.Interceptor} that controls access to {@link BackingStore}
+ * An {@link org.apache.ldap.server.interceptor.Interceptor} that controls access to {@link ContextPartition}
  * operations.  If a user tries to perform any operations that requires
  * permission he or she doesn't have, {@link NamingException} will be
  * thrown and therefore the current invocation chain will terminate.

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/exception/ExceptionService.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/exception/ExceptionService.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetMatchedDN.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetMatchedDN.java Mon Jun 20 06:33:00 2005
@@ -20,7 +20,7 @@
 import javax.naming.Name;
 import javax.naming.NamingException;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 import org.apache.ldap.server.partition.PartitionNexus;
 
 
@@ -50,7 +50,7 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         return ( ( PartitionNexus ) store ).getMatchedDn( getName(), isNormalized() );
     }

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetSuffix.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetSuffix.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetSuffix.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetSuffix.java Mon Jun 20 06:33:00 2005
@@ -20,7 +20,6 @@
 import javax.naming.Name;
 import javax.naming.NamingException;
 
-import org.apache.ldap.server.partition.BackingStore;
 import org.apache.ldap.server.partition.ContextPartition;
 
 
@@ -50,8 +49,8 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
-        return ( ( ContextPartition ) store ).getSuffix( normalized );
+        return store.getSuffix( normalized );
     }
 }

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/HasEntry.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/HasEntry.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ListSuffixes.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ListSuffixes.java Mon Jun 20 06:33:00 2005
@@ -19,7 +19,7 @@
 
 import javax.naming.NamingException;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 import org.apache.ldap.server.partition.PartitionNexus;
 
 
@@ -48,7 +48,7 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         return ( ( PartitionNexus ) store ).listSuffixes( normalized );
     }

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Lookup.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Lookup.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/DefaultContextFactoryConfiguration.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/DefaultContextFactoryConfiguration.java Mon Jun 20 06:33:00 2005
@@ -48,11 +48,11 @@
 import org.apache.ldap.server.partition.ContextPartition;
 import org.apache.ldap.server.partition.PartitionNexus;
 import org.apache.ldap.server.partition.RootNexus;
-import org.apache.ldap.server.partition.store.DefaultSearchEngine;
-import org.apache.ldap.server.partition.store.ExpressionEnumerator;
-import org.apache.ldap.server.partition.store.ExpressionEvaluator;
-import org.apache.ldap.server.partition.store.PartitionStore;
-import org.apache.ldap.server.partition.store.SearchEngine;
+import org.apache.ldap.server.partition.store.impl.btree.DefaultSearchEngine;
+import org.apache.ldap.server.partition.store.impl.btree.ExpressionEnumerator;
+import org.apache.ldap.server.partition.store.impl.btree.ExpressionEvaluator;
+import org.apache.ldap.server.partition.store.impl.btree.PartitionStore;
+import org.apache.ldap.server.partition.store.impl.btree.SearchEngine;
 import org.apache.ldap.server.partition.store.impl.btree.jdbm.JdbmPartitionStore;
 import org.apache.ldap.server.schema.AttributeTypeRegistry;
 import org.apache.ldap.server.schema.ConcreteNameComponentNormalizer;
@@ -230,7 +230,7 @@
         try
         {
             this.rootNexus.sync();
-            this.rootNexus.close();
+            this.rootNexus.destroy();
             this.interceptorChain.destroy();
             this.started = false;
         }

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/RootNexusProxy.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/RootNexusProxy.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/RootNexusProxy.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/RootNexusProxy.java Mon Jun 20 06:33:00 2005
@@ -140,7 +140,7 @@
         this.provider.shutdown();
     }
 
-    public boolean isOpen() {
-        return this.provider.getRootNexus().isOpen();
+    public boolean isInitialized() {
+        return this.provider.getRootNexus().isInitialized();
     }
 }

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/SystemPartition.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/SystemPartition.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/SystemPartition.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/SystemPartition.java Mon Jun 20 06:33:00 2005
@@ -27,8 +27,8 @@
 import org.apache.ldap.common.util.DateUtils;
 import org.apache.ldap.common.util.NamespaceTools;
 import org.apache.ldap.server.partition.AbstractContextPartition;
-import org.apache.ldap.server.partition.store.PartitionStore;
-import org.apache.ldap.server.partition.store.SearchEngine;
+import org.apache.ldap.server.partition.store.impl.btree.PartitionStore;
+import org.apache.ldap.server.partition.store.impl.btree.SearchEngine;
 
 
 /**
@@ -219,7 +219,7 @@
 
 
     /**
-     * @see org.apache.ldap.server.partition.BackingStore#isSuffix(javax.naming.Name)
+     * @see org.apache.ldap.server.partition.ContextPartition#isSuffix(javax.naming.Name)
      */
     public final boolean isSuffix( Name dn )
     {

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/normalization/NormalizationService.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/normalization/NormalizationService.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/normalization/NormalizationService.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/normalization/NormalizationService.java Mon Jun 20 06:33:00 2005
@@ -70,7 +70,7 @@
 
 
     // ------------------------------------------------------------------------
-    // Normalize all Name based arguments for BackingStore interface operations
+    // Normalize all Name based arguments for ContextPartition interface operations
     // ------------------------------------------------------------------------
 
 

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/operational/OperationalAttributeService.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/operational/OperationalAttributeService.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/operational/OperationalAttributeService.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/operational/OperationalAttributeService.java Mon Jun 20 06:33:00 2005
@@ -47,8 +47,8 @@
 import org.apache.ldap.server.invocation.MoveAndModifyRN;
 import org.apache.ldap.server.invocation.Search;
 import org.apache.ldap.server.partition.RootNexus;
-import org.apache.ldap.server.partition.store.ResultFilteringEnumeration;
-import org.apache.ldap.server.partition.store.SearchResultFilter;
+import org.apache.ldap.server.partition.store.impl.btree.ResultFilteringEnumeration;
+import org.apache.ldap.server.partition.store.impl.btree.SearchResultFilter;
 import org.apache.ldap.server.schema.AttributeTypeRegistry;
 
 

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/AbstractContextPartition.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/AbstractContextPartition.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/AbstractContextPartition.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/AbstractContextPartition.java Mon Jun 20 06:33:00 2005
@@ -35,15 +35,15 @@
 import org.apache.ldap.common.message.LockableAttributesImpl;
 import org.apache.ldap.common.schema.AttributeType;
 import org.apache.ldap.common.util.ArrayUtils;
-import org.apache.ldap.server.partition.store.PartitionStore;
-import org.apache.ldap.server.partition.store.SearchEngine;
-import org.apache.ldap.server.partition.store.SearchResultEnumeration;
+import org.apache.ldap.server.partition.store.impl.btree.PartitionStore;
+import org.apache.ldap.server.partition.store.impl.btree.SearchEngine;
+import org.apache.ldap.server.partition.store.impl.btree.SearchResultEnumeration;
 import org.apache.ldap.server.partition.store.impl.gui.PartitionViewer;
 
 
 /**
- * An Abstract BackingStore using a formal database and a search engine.  All
- * the common code between a SystemBackingStore and a DefaultBackingStore
+ * An Abstract ContextPartition using a formal database and a search engine.  All
+ * the common code between a SystemContextPartition and a DefaultContextPartition
  * will be added to this super class.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
@@ -221,13 +221,10 @@
 
 
     // ------------------------------------------------------------------------
-    // BackingStore Interface Method Implementations
+    // ContextPartition Interface Method Implementations
     // ------------------------------------------------------------------------
 
 
-    /**
-     * @see org.apache.ldap.server.partition.BackingStore#delete( Name )
-     */
     public void delete( Name dn ) throws NamingException
     {
         BigInteger id = db.getEntryId( dn.toString() );
@@ -251,36 +248,24 @@
     }
     
 
-    /**
-     * @see org.apache.ldap.server.partition.BackingStore#add( String, Name, Attributes )
-     */
     public void add( String updn, Name dn, Attributes entry ) throws NamingException
     {
         db.add( updn, dn, entry );
     }
 
 
-    /**
-     * @see org.apache.ldap.server.partition.BackingStore#modify( Name, int, Attributes )
-     */
     public void modify( Name dn, int modOp, Attributes mods ) throws NamingException
     {
         db.modify( dn, modOp, mods );
     }
 
 
-    /**
-     * @see org.apache.ldap.server.partition.BackingStore#modify( Name,ModificationItem[] )
-     */
     public void modify( Name dn, ModificationItem[] mods ) throws NamingException
     {
         db.modify( dn, mods );
     }
 
 
-    /**
-     * @see org.apache.ldap.server.partition.BackingStore#list( Name )
-     */
     public NamingEnumeration list( Name base ) throws NamingException
     {
         SearchResultEnumeration list;
@@ -290,9 +275,6 @@
     }
     
     
-    /**
-     * @see org.apache.ldap.server.partition.BackingStore#search(Name, Map, ExprNode, SearchControls)
-     */
     public NamingEnumeration search( Name base, Map env, ExprNode filter,
                                      SearchControls searchCtls )
         throws NamingException
@@ -306,18 +288,12 @@
     }
 
 
-    /**
-     * @see org.apache.ldap.server.partition.BackingStore#lookup( Name )
-     */
     public Attributes lookup( Name dn ) throws NamingException
     {
         return db.lookup( db.getEntryId( dn.toString() ) );
     }
 
 
-    /**
-     * @see BackingStore#lookup(Name,String[])
-     */
     public Attributes lookup( Name dn, String [] attrIds ) throws NamingException
     {
         if ( attrIds == null || attrIds.length == 0 )
@@ -342,36 +318,24 @@
     }
 
 
-    /**
-     * @see org.apache.ldap.server.partition.BackingStore#hasEntry( Name )
-     */
     public boolean hasEntry( Name dn ) throws NamingException
     {
         return null != db.getEntryId( dn.toString() );
     }
 
 
-    /**
-     * @see BackingStore#modifyRn( Name, String, boolean )
-     */
     public void modifyRn( Name dn, String newRdn, boolean deleteOldRdn ) throws NamingException
     {
         db.modifyRdn( dn, newRdn, deleteOldRdn );
     }
 
 
-    /**
-     * @see org.apache.ldap.server.partition.BackingStore#move( Name, Name )
-     */
     public void move( Name oldChildDn, Name newParentDn ) throws NamingException
     {
         db.move( oldChildDn, newParentDn );
     }
     
 
-    /**
-     * @see org.apache.ldap.server.partition.BackingStore#move( Name, Name, String, boolean )
-     */
     public void move( Name oldChildDn, Name newParentDn, String newRdn,
         boolean deleteOldRdn ) throws NamingException
     {
@@ -385,13 +349,13 @@
     }
 
 
-    public void close() throws NamingException
+    public void destroy() throws NamingException
     {
         db.close();
     }
 
 
-    public boolean isOpen()
+    public boolean isInitialized()
     {
         return db.isOpen();
     }

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ApplicationPartition.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ApplicationPartition.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ApplicationPartition.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ApplicationPartition.java Mon Jun 20 06:33:00 2005
@@ -21,8 +21,8 @@
 import javax.naming.NamingException;
 
 import org.apache.ldap.common.schema.AttributeType;
-import org.apache.ldap.server.partition.store.PartitionStore;
-import org.apache.ldap.server.partition.store.SearchEngine;
+import org.apache.ldap.server.partition.store.impl.btree.PartitionStore;
+import org.apache.ldap.server.partition.store.impl.btree.SearchEngine;
 
 
 /**
@@ -77,9 +77,6 @@
         this.normalizedSuffix = normSuffix;
     }
 
-    /**
-     * @see ContextPartition#getSuffix( boolean )
-     */
     public Name getSuffix( boolean normalized )
     {
         if ( normalized )
@@ -91,9 +88,6 @@
     }
 
 
-    /**
-     * @see BackingStore#isSuffix( Name )
-     */
     public boolean isSuffix( Name dn ) throws NamingException
     {
         return normalizedSuffix.equals( dn ) ;

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ContextPartition.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ContextPartition.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ContextPartition.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/ContextPartition.java Mon Jun 20 06:33:00 2005
@@ -17,34 +17,238 @@
 package org.apache.ldap.server.partition;
 
 
+import java.util.Map;
+
 import javax.naming.Name;
+import javax.naming.NamingEnumeration;
 import javax.naming.NamingException;
+import javax.naming.directory.Attributes;
+import javax.naming.directory.ModificationItem;
+import javax.naming.directory.SearchControls;
+
+import org.apache.ldap.common.filter.ExprNode;
 
 
 /**
- * ContextPartitions are indivisible BackingStores associated with a naming
+ * ContextPartitions are indivisible ContextPartitions associated with a naming
  * context as a base suffix.  All JNDI Attributes entries at and under the
  * context of this suffix are stored within this partition.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$
  */
-public interface ContextPartition extends BackingStore
+public interface ContextPartition
 {
     /**
      * Initializes this partition.
      */
     void init( Name userProvidedSuffix, Name normalizedSuffix ) throws NamingException;
     
+    
+    /**
+     * Closes or shuts down this ContextPartition.  Operations against closed
+     * ContextPartitions will fail.
+     *
+     * @throws NamingException if there are problems shutting down
+     */
+    void destroy() throws NamingException;
+
+    /**
+     * Checks to see if this partition is initialized or not.
+     */
+    boolean isInitialized();
+
+    /**
+     * Cue to ContextPartitions with caches to flush entry and index changes to disk.
+     *
+     * @throws NamingException if there are problems flushing caches
+     */
+    void sync() throws NamingException;
+
+    
     /**
      * Gets the distinguished/absolute name of the suffix for all entries
-     * stored within this BackingStore.
+     * stored within this ContextPartition.
      *
      * @param normalized boolean value used to control the normalization of the
      * returned Name.  If true the normalized Name is returned, otherwise the 
      * original user provided Name without normalization is returned.
      * @return Name representing the distinguished/absolute name of this
-     * BackingStores root context.
+     * ContextPartitions root context.
      */
     Name getSuffix( boolean normalized ) ;
+
+    
+    /**
+     * Deletes a leaf entry from this ContextPartition: non-leaf entries cannot be 
+     * deleted until this operation has been applied to their children.
+     *
+     * @param name the normalized distinguished/absolute name of the entry to
+     * delete from this ContextPartition.
+     * @throws NamingException if there are any problems
+     */ 
+    void delete( Name name ) throws NamingException;
+
+    /**
+     * Adds an entry to this ContextPartition.
+     *
+     * @param upName the user provided distinguished/absolute name of the entry
+     * @param normName the normalized distinguished/absolute name of the entry
+     * @param entry the entry to add to this ContextPartition
+     * @throws NamingException if there are any problems
+     */
+    void add( String upName, Name normName, Attributes entry ) throws NamingException;
+
+    /**
+     * Modifies an entry by adding, removing or replacing a set of attributes.
+     *
+     * @param name the normalized distinguished/absolute name of the entry to
+     * modify
+     * @param modOp the modification operation to perform on the entry which
+     * is one of constants specified by the DirContext interface:
+     * <code>ADD_ATTRIBUTE, REMOVE_ATTRIBUTE, REPLACE_ATTRIBUTE</code>.
+     * @param mods the attributes and their values used to affect the
+     * modification with.
+     * @throws NamingException if there are any problems
+     * @see javax.naming.directory.DirContext
+     * @see javax.naming.directory.DirContext#ADD_ATTRIBUTE
+     * @see javax.naming.directory.DirContext#REMOVE_ATTRIBUTE
+     * @see javax.naming.directory.DirContext#REPLACE_ATTRIBUTE
+     */
+    void modify( Name name, int modOp, Attributes mods ) throws NamingException;
+
+    /**
+     * Modifies an entry by using a combination of adds, removes or replace 
+     * operations using a set of ModificationItems.
+     *
+     * @param name the normalized distinguished/absolute name of the entry to modify
+     * @param mods the ModificationItems used to affect the modification with
+     * @throws NamingException if there are any problems
+     * @see ModificationItem
+     */
+    void modify( Name name, ModificationItem [] mods ) throws NamingException;
+
+    /**
+     * A specialized form of one level search used to return a minimal set of 
+     * information regarding child entries under a base.  Convenience method
+     * used to optimize operations rather than conducting a full search with 
+     * retrieval.
+     *
+     * @param base the base distinguished/absolute name for the search/listing
+     * @return a NamingEnumeration containing objects of type
+     * {@link org.apache.ldap.server.partition.store.impl.btree.jdbm.PartitionStoreSearchResult}
+     * @throws NamingException if there are any problems
+     */
+    NamingEnumeration list( Name base ) throws NamingException;
+    
+    /**
+     * Conducts a search against this ContextPartition.  Namespace specific
+     * parameters for search are contained within the environment using
+     * namespace specific keys into the hash.  For example in the LDAP namespace
+     * a ContextPartition implementation may look for search Controls using a
+     * namespace specific or implementation specific key for the set of LDAP
+     * Controls.
+     *
+     * @param base the normalized distinguished/absolute name of the search base
+     * @param env the environment under which operation occurs
+     * @param filter the root node of the filter expression tree
+     * @param searchCtls the search controls
+     * @throws NamingException if there are any problems
+     * @return a NamingEnumeration containing objects of type 
+     * <a href="http://java.sun.com/j2se/1.4.2/docs/api/
+     * javax/naming/directory/SearchResult.html">SearchResult</a>.
+     */
+    NamingEnumeration search( Name base, Map env, ExprNode filter,
+        SearchControls searchCtls ) throws NamingException;
+
+    /**
+     * Looks up an entry by distinguished/absolute name.  This is a simplified
+     * version of the search operation used to point read an entry used for
+     * convenience.
+     *
+     * @param name the normalized distinguished name of the object to lookup
+     * @return an Attributes object representing the entry
+     * @throws NamingException if there are any problems
+     */
+    Attributes lookup( Name name ) throws NamingException;
+
+    /**
+     * Looks up an entry by distinguished name.  This is a simplified version
+     * of the search operation used to point read an entry used for convenience
+     * with a set of attributes to return.  If the attributes are null or emty
+     * this defaults to the lookup opertion without the attributes.
+     *
+     * @param dn the normalized distinguished name of the object to lookup
+     * @param attrIds the set of attributes to return
+     * @return an Attributes object representing the entry
+     * @throws NamingException if there are any problems
+     */
+    Attributes lookup( Name dn, String [] attrIds ) throws NamingException;
+
+    /**
+     * Fast operation to check and see if a particular entry exists.
+     *
+     * @param name the normalized distinguished/absolute name of the object to
+     * check for existance
+     * @return true if the entry exists, false if it does not
+     * @throws NamingException if there are any problems
+     */
+    boolean hasEntry( Name name ) throws NamingException;
+
+    /**
+     * Checks to see if name is a context suffix.
+     *
+     * @param name the normalized distinguished/absolute name of the context
+     * @return true if the name is a context suffix, false if it is not.
+     * @throws NamingException if there are any problems
+     */
+    boolean isSuffix( Name name ) throws NamingException;
+
+    /**
+     * Modifies an entry by changing its relative name. Optionally attributes
+     * associated with the old relative name can be removed from the entry.
+     * This makes sense only in certain namespaces like LDAP and will be ignored
+     * if it is irrelavent.
+     *
+     * @param name the normalized distinguished/absolute name of the entry to
+     * modify the RN of.
+     * @param newRn the new RN of the entry specified by name
+     * @param deleteOldRn boolean flag which removes the old RN attribute
+     * from the entry if set to true, and has no affect if set to false
+     * @throws NamingException if there are any problems
+     */
+    void modifyRn( Name name, String newRn, boolean deleteOldRn )
+        throws NamingException;
+
+    /**
+     * Transplants a child entry, to a position in the namespace under a new
+     * parent entry.
+     *
+     * @param newParentName the normalized distinguished/absolute name of the
+     * new parent to move the target entry to
+     * @param oriChildName the normalized distinguished/absolute name of the
+     * original child name representing the child entry to move
+     * @throws NamingException if there are any problems
+     */
+    void move( Name oriChildName, Name newParentName ) throws NamingException;
+
+    /**
+     * Transplants a child entry, to a position in the namespace under a new
+     * parent entry and changes the RN of the child entry which can optionally
+     * have its old RN attributes removed.  The removal of old RN attributes
+     * may not make sense in all namespaces.  If the concept is undefined in a
+     * namespace this parameters is ignored.  An example of a namespace where
+     * this parameter is significant is the LDAP namespace.
+     *
+     * @param oriChildName the normalized distinguished/absolute name of the
+     * original child name representing the child entry to move
+     * @param newParentName the normalized distinguished/absolute name of the
+     * new parent to move the targeted entry to
+     * @param newRn the new RN of the entry
+     * @param deleteOldRn boolean flag which removes the old RN attribute
+     * from the entry if set to true, and has no affect if set to false
+     * @throws NamingException if there are any problems
+     */
+    void move( Name oriChildName, Name newParentName, String newRn,
+               boolean deleteOldRn ) throws NamingException;
 }

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/PartitionNexus.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/PartitionNexus.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/RootNexus.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/RootNexus.java Mon Jun 20 06:33:00 2005
@@ -48,6 +48,8 @@
 /**
  * A nexus for partitions dedicated for storing entries specific to a naming
  * context.
+ * 
+ * TODO init() should initialize all mounted child partitions. (destroy too)
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$
@@ -215,7 +217,7 @@
     
     
     /**
-     * @see BackingStore#delete(javax.naming.Name)
+     * @see ContextPartition#delete(javax.naming.Name)
      */
     public void delete( Name dn ) throws NamingException
     {
@@ -232,7 +234,7 @@
      * here so backend implementors do not have to worry about performing these
      * kinds of checks.
      *
-     * @see org.apache.ldap.server.partition.BackingStore#add(String, Name, Attributes)
+     * @see org.apache.ldap.server.partition.ContextPartition#add(String, Name, Attributes)
      */
     public void add( String updn, Name dn, Attributes an_entry ) throws NamingException
     {
@@ -243,7 +245,7 @@
 
 
     /**
-     * @see BackingStore#modify(Name, int,Attributes)
+     * @see ContextPartition#modify(Name, int,Attributes)
      */
     public void modify( Name dn, int modOp, Attributes mods ) throws NamingException
     {
@@ -254,7 +256,7 @@
 
 
     /**
-     * @see BackingStore#modify(javax.naming.Name,
+     * @see ContextPartition#modify(javax.naming.Name,
      * javax.naming.directory.ModificationItem[])
      */
     public void modify( Name dn, ModificationItem[] mods ) throws NamingException
@@ -266,7 +268,7 @@
 
     
     /**
-     * @see BackingStore#list(javax.naming.Name)
+     * @see ContextPartition#list(javax.naming.Name)
      */
     public NamingEnumeration list( Name base ) throws NamingException
     {
@@ -277,7 +279,7 @@
     
 
     /**
-     * @see BackingStore#search(Name, Map, ExprNode, SearchControls)
+     * @see ContextPartition#search(Name, Map, ExprNode, SearchControls)
      */
     public NamingEnumeration search( Name base, Map env, ExprNode filter, SearchControls searchCtls )
             throws NamingException
@@ -341,7 +343,7 @@
 
 
     /**
-     * @see BackingStore#lookup(javax.naming.Name)
+     * @see ContextPartition#lookup(javax.naming.Name)
      */
     public Attributes lookup( Name dn )  throws NamingException
     {
@@ -361,7 +363,7 @@
 
 
     /**
-     * @see org.apache.ldap.server.partition.BackingStore#lookup(javax.naming.Name, String[])
+     * @see org.apache.ldap.server.partition.ContextPartition#lookup(javax.naming.Name, String[])
      */
     public Attributes lookup( Name dn, String[] attrIds )  throws NamingException
     {
@@ -392,7 +394,7 @@
 
 
     /**
-     * @see BackingStore#hasEntry(javax.naming.Name)
+     * @see ContextPartition#hasEntry(javax.naming.Name)
      */
     public boolean hasEntry( Name dn ) throws NamingException
     {
@@ -408,7 +410,7 @@
 
     
     /**
-     * @see BackingStore#isSuffix(javax.naming.Name)
+     * @see ContextPartition#isSuffix(javax.naming.Name)
      */
     public boolean isSuffix( Name dn ) throws NamingException
     {
@@ -417,7 +419,7 @@
 
     
     /**
-     * @see BackingStore#modifyRn(Name, String, boolean)
+     * @see ContextPartition#modifyRn(Name, String, boolean)
      */
     public void modifyRn( Name dn, String newRdn, boolean deleteOldRdn ) throws NamingException
     {
@@ -428,7 +430,7 @@
     
     
     /**
-     * @see BackingStore#move(Name, Name)
+     * @see ContextPartition#move(Name, Name)
      */
     public void move( Name oriChildName, Name newParentName ) throws NamingException
     {
@@ -439,7 +441,7 @@
     
     
     /**
-     * @see BackingStore#move(javax.naming.Name,
+     * @see ContextPartition#move(javax.naming.Name,
      * javax.naming.Name, java.lang.String, boolean)
      */
     public void move( Name oldChildDn, Name newParentDn, String newRdn,
@@ -452,7 +454,7 @@
 
 
     /**
-     * @see BackingStore#sync()
+     * @see ContextPartition#sync()
      */
     public void sync() throws NamingException
     {
@@ -462,7 +464,7 @@
 
         while ( list.hasNext() )
         {
-            BackingStore store = ( BackingStore ) list.next();
+            ContextPartition store = ( ContextPartition ) list.next();
 
             try
             {
@@ -493,16 +495,13 @@
     }
 
 
-    public boolean isOpen()
+    public boolean isInitialized()
     {
         return open;
     }
 
 
-    /**
-     * @see org.apache.ldap.server.partition.BackingStore#close()
-     */
-    public synchronized void close() throws NamingException
+    public synchronized void destroy() throws NamingException
     {
         if ( !open )
         {
@@ -517,12 +516,12 @@
         // have an attempt at closing down and synching their cached entries
         while ( list.hasNext() )
         {
-            BackingStore store = ( BackingStore ) list.next();
+            ContextPartition store = ( ContextPartition ) list.next();
 
             try
             {
                 store.sync();
-                store.close();
+                store.destroy();
             }
             catch ( NamingException e )
             {

Copied: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DefaultOptimizer.java (from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DefaultOptimizer.java)
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DefaultOptimizer.java?p2=directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DefaultOptimizer.java&p1=directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DefaultOptimizer.java&r1=191456&r2=191462&rev=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DefaultOptimizer.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DefaultOptimizer.java Mon Jun 20 06:33:00 2005
@@ -14,7 +14,7 @@
  *   limitations under the License.
  *
  */
-package org.apache.ldap.server.partition.store;
+package org.apache.ldap.server.partition.store.impl.btree;
 
 
 import java.math.BigInteger;

Copied: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DefaultSearchEngine.java (from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DefaultSearchEngine.java)
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DefaultSearchEngine.java?p2=directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DefaultSearchEngine.java&p1=directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DefaultSearchEngine.java&r1=191456&r2=191462&rev=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DefaultSearchEngine.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DefaultSearchEngine.java Mon Jun 20 06:33:00 2005
@@ -14,7 +14,7 @@
  *   limitations under the License.
  *
  */
-package org.apache.ldap.server.partition.store;
+package org.apache.ldap.server.partition.store.impl.btree;
 
 
 import java.math.BigInteger;

Copied: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DisjunctionEnumeration.java (from r191456, directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DisjunctionEnumeration.java)
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DisjunctionEnumeration.java?p2=directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DisjunctionEnumeration.java&p1=directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DisjunctionEnumeration.java&r1=191456&r2=191462&rev=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/DisjunctionEnumeration.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/store/impl/btree/DisjunctionEnumeration.java Mon Jun 20 06:33:00 2005
@@ -14,7 +14,7 @@
  *   limitations under the License.
  *
  */
-package org.apache.ldap.server.partition.store;
+package org.apache.ldap.server.partition.store.impl.btree;
 
 
 import java.util.HashMap;
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/exception/ExceptionService.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/exception/ExceptionService.java Mon Jun 20 06:33:00 2005
@@ -43,13 +43,13 @@
 import org.apache.ldap.server.invocation.Move;
 import org.apache.ldap.server.invocation.MoveAndModifyRN;
 import org.apache.ldap.server.invocation.Search;
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 import org.apache.ldap.server.partition.RootNexus;
 
 
 /**
  * An {@link org.apache.ldap.server.interceptor.Interceptor} that detects any operations that breaks integrity
  * of {@link BackingStore} and terminates the current invocation chain by
  * throwing a {@link NamingException}. Those operations include when an entry
  * already exists at a DN and is added once again to the same DN.
  *
@@ -43,13 +43,13 @@
 /**
  * An {@link org.apache.ldap.server.interceptor.Interceptor} that detects any operations that breaks integrity
- * of {@link BackingStore} and terminates the current invocation chain by
+ * of {@link ContextPartition} and terminates the current invocation chain by
  * throwing a {@link NamingException}. Those operations include when an entry
  * already exists at a DN and is added once again to the same DN.

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/interceptor/Interceptor.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/interceptor/Interceptor.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/interceptor/Interceptor.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/interceptor/Interceptor.java Mon Jun 20 06:33:00 2005
@@ -21,12 +21,12 @@
 
 import org.apache.ldap.server.configuration.StartupConfiguration;
 import org.apache.ldap.server.invocation.Invocation;
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Filters any directory operations.  You can filter any {@link Invocation}
  * performed on {@link BackingStore}s just like Servlet filters do.
  * <p/>
  * <h2>Interceptor Chaining</h2> Interceptors should usually pass the control
  * of current invocation to the next interceptor by calling
@@ -21,12 +21,12 @@
 /**
  * Filters any directory operations.  You can filter any {@link Invocation}
- * performed on {@link BackingStore}s just like Servlet filters do.
+ * performed on {@link ContextPartition}s just like Servlet filters do.
  * <p/>
  * <h2>Interceptor Chaining</h2> Interceptors should usually pass the control

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Add.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Add.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Add.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Add.java Mon Jun 20 06:33:00 2005
@@ -21,11 +21,11 @@
 import javax.naming.NamingException;
 import javax.naming.directory.Attributes;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Represents an {@link Invocation} on {@link BackingStore#add(String, Name, Attributes)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -71,7 +71,7 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         store.add( userProvidedName, getName(), attributes );
         return null;
@@ -21,11 +21,11 @@
 
 /**
- * Represents an {@link Invocation} on {@link BackingStore#add(String, Name, Attributes)}.
+ * Represents an {@link Invocation} on {@link ContextPartition#add(String, Name, Attributes)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Delete.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Delete.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Delete.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Delete.java Mon Jun 20 06:33:00 2005
@@ -20,11 +20,11 @@
 import javax.naming.Name;
 import javax.naming.NamingException;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Represents an {@link Invocation} on {@link BackingStore#delete(Name)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -38,7 +38,7 @@
         super( name );
     }
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         store.delete( getName() );
 
@@ -20,11 +20,11 @@
 
 /**
- * Represents an {@link Invocation} on {@link BackingStore#delete(Name)}.
+ * Represents an {@link Invocation} on {@link ContextPartition#delete(Name)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/EntryInvocation.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/EntryInvocation.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/EntryInvocation.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/EntryInvocation.java Mon Jun 20 06:33:00 2005
@@ -20,10 +20,10 @@
 
 import javax.naming.Name;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 /**
  * Represents a method invocation on a single entry in {@link BackingStore}s.
  * <p/>
  * This class is abstract, and developers should extend this class to
  * represent the actual method invocations.
@@ -20,10 +20,10 @@
 
 /**
- * Represents a method invocation on a single entry in {@link BackingStore}s.
+ * Represents a method invocation on a single entry in {@link ContextPartition}s.
  * <p/>
  * This class is abstract, and developers should extend this class to

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetMatchedDN.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/GetMatchedDN.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/HasEntry.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/HasEntry.java Mon Jun 20 06:33:00 2005
@@ -20,11 +20,11 @@
 import javax.naming.Name;
 import javax.naming.NamingException;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Represents an {@link Invocation} on {@link BackingStore#hasEntry(Name)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -39,7 +39,7 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         return store.hasEntry( getName() ) ? Boolean.TRUE : Boolean.FALSE;
     }
@@ -20,11 +20,11 @@
 
 /**
- * Represents an {@link Invocation} on {@link BackingStore#hasEntry(Name)}.
+ * Represents an {@link Invocation} on {@link ContextPartition#hasEntry(Name)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Invocation.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Invocation.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Invocation.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Invocation.java Mon Jun 20 06:33:00 2005
@@ -22,11 +22,11 @@
 
 import javax.naming.NamingException;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Represents a method invocation on {@link BackingStore}s.
  * <p/>
  * This class is abstract, and developers should extend this class to
  * represent the actual method invocations.
@@ -94,12 +94,12 @@
 
     /**
      * Executes this invocation on the specified <code>store</code>. The default
-     * implementation calls an abstract method {@link #doExecute(BackingStore)}
+     * implementation calls an abstract method {@link #doExecute(ContextPartition)}
      * and sets the <code>returnValue</code> property of this invocation to its return value.
      *
      * @throws NamingException if the operation failed
      */
-    public void execute( BackingStore store ) throws NamingException
+    public void execute( ContextPartition store ) throws NamingException
     {
         setReturnValue( doExecute( store ) );
     }
@@ -111,5 +111,5 @@
      *
      * @throws NamingException if the operation failed
      */
-    protected abstract Object doExecute( BackingStore store ) throws NamingException;
+    protected abstract Object doExecute( ContextPartition store ) throws NamingException;
 }
@@ -22,11 +22,11 @@
 
 /**
- * Represents a method invocation on {@link BackingStore}s.
+ * Represents a method invocation on {@link ContextPartition}s.
  * <p/>
  * This class is abstract, and developers should extend this class to

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/IsSuffix.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/IsSuffix.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/IsSuffix.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/IsSuffix.java Mon Jun 20 06:33:00 2005
@@ -20,11 +20,11 @@
 import javax.naming.Name;
 import javax.naming.NamingException;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Represents an {@link Invocation} on {@link BackingStore#isSuffix(Name)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -39,7 +39,7 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         return store.isSuffix( getName() ) ? Boolean.TRUE : Boolean.FALSE;
     }
@@ -20,11 +20,11 @@
 
 /**
- * Represents an {@link Invocation} on {@link BackingStore#isSuffix(Name)}.
+ * Represents an {@link Invocation} on {@link ContextPartition#isSuffix(Name)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/List.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/List.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/List.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/List.java Mon Jun 20 06:33:00 2005
@@ -20,11 +20,11 @@
 import javax.naming.Name;
 import javax.naming.NamingException;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Represents an {@link org.apache.ldap.server.invocation.Invocation} on {@link BackingStore#list(Name)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -40,7 +40,7 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         return store.list( getBaseName() );
     }
@@ -20,11 +20,11 @@
 
 /**
- * Represents an {@link org.apache.ldap.server.invocation.Invocation} on {@link BackingStore#list(Name)}.
+ * Represents an {@link org.apache.ldap.server.invocation.Invocation} on {@link ContextPartition#list(Name)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ListSuffixes.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ListSuffixes.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Lookup.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Lookup.java Mon Jun 20 06:33:00 2005
@@ -20,11 +20,11 @@
 import javax.naming.Name;
 import javax.naming.NamingException;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Represents an {@link org.apache.ldap.server.invocation.Invocation} on {@link BackingStore#lookup(Name)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -39,7 +39,7 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         return store.lookup( getName() );
     }
@@ -20,11 +20,11 @@
 
 /**
- * Represents an {@link org.apache.ldap.server.invocation.Invocation} on {@link BackingStore#lookup(Name)}.
+ * Represents an {@link org.apache.ldap.server.invocation.Invocation} on {@link ContextPartition#lookup(Name)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/LookupWithAttrIds.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/LookupWithAttrIds.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/LookupWithAttrIds.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/LookupWithAttrIds.java Mon Jun 20 06:33:00 2005
@@ -20,11 +20,11 @@
 import javax.naming.Name;
 import javax.naming.NamingException;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Represents an {@link Invocation} on {@link BackingStore#lookup(Name, String[])}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -49,7 +49,7 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         return store.lookup( getName(), attributeIds );
     }
@@ -20,11 +20,11 @@
 
 /**
- * Represents an {@link Invocation} on {@link BackingStore#lookup(Name, String[])}.
+ * Represents an {@link Invocation} on {@link ContextPartition#lookup(Name, String[])}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Modify.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Modify.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Modify.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Modify.java Mon Jun 20 06:33:00 2005
@@ -21,11 +21,11 @@
 import javax.naming.NamingException;
 import javax.naming.directory.Attributes;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Represents an {@link Invocation} on {@link BackingStore#modify(Name, int, Attributes)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -59,7 +59,7 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         store.modify( getName(), modOp, attributes );
         return null;
@@ -21,11 +21,11 @@
 
 /**
- * Represents an {@link Invocation} on {@link BackingStore#modify(Name, int, Attributes)}.
+ * Represents an {@link Invocation} on {@link ContextPartition#modify(Name, int, Attributes)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ModifyMany.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ModifyMany.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ModifyMany.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ModifyMany.java Mon Jun 20 06:33:00 2005
@@ -21,11 +21,11 @@
 import javax.naming.NamingException;
 import javax.naming.directory.ModificationItem;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Represents an {@link Invocation} on {@link BackingStore#modify(Name, ModificationItem[])}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -54,7 +54,7 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         store.modify( getName(), modificationItems );
         return null;
@@ -21,11 +21,11 @@
 
 /**
- * Represents an {@link Invocation} on {@link BackingStore#modify(Name, ModificationItem[])}.
+ * Represents an {@link Invocation} on {@link ContextPartition#modify(Name, ModificationItem[])}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ModifyRN.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ModifyRN.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ModifyRN.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/ModifyRN.java Mon Jun 20 06:33:00 2005
@@ -20,11 +20,11 @@
 import javax.naming.Name;
 import javax.naming.NamingException;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Represents an {@link Invocation} on {@link BackingStore#modifyRn(Name, String, boolean)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -65,7 +65,7 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         store.modifyRn( getName(), newRelativeName, deleteOldName );
         return null;
@@ -20,11 +20,11 @@
 
 /**
- * Represents an {@link Invocation} on {@link BackingStore#modifyRn(Name, String, boolean)}.
+ * Represents an {@link Invocation} on {@link ContextPartition#modifyRn(Name, String, boolean)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Move.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Move.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Move.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Move.java Mon Jun 20 06:33:00 2005
@@ -20,11 +20,11 @@
 import javax.naming.Name;
 import javax.naming.NamingException;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Represents an {@link Invocation} on {@link BackingStore#move(Name, Name)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -60,7 +60,7 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         store.move( getName(), newParentName );
         return null;
@@ -20,11 +20,11 @@
 
 /**
- * Represents an {@link Invocation} on {@link BackingStore#move(Name, Name)}.
+ * Represents an {@link Invocation} on {@link ContextPartition#move(Name, Name)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/MoveAndModifyRN.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/MoveAndModifyRN.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/MoveAndModifyRN.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/MoveAndModifyRN.java Mon Jun 20 06:33:00 2005
@@ -20,11 +20,11 @@
 import javax.naming.Name;
 import javax.naming.NamingException;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Represents an {@link org.apache.ldap.server.invocation.Invocation} on {@link BackingStore#move(Name, Name, String, boolean)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -84,7 +84,7 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         store.move( getName(), newParentName, newRelativeName, deleteOldName );
         return null;
@@ -20,11 +20,11 @@
 
 /**
- * Represents an {@link org.apache.ldap.server.invocation.Invocation} on {@link BackingStore#move(Name, Name, String, boolean)}.
+ * Represents an {@link org.apache.ldap.server.invocation.Invocation} on {@link ContextPartition#move(Name, Name, String, boolean)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Search.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Search.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Search.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/Search.java Mon Jun 20 06:33:00 2005
@@ -24,11 +24,11 @@
 import javax.naming.directory.SearchControls;
 
 import org.apache.ldap.common.filter.ExprNode;
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 
 /**
  * Represents an {@link Invocation} on {@link BackingStore#search(Name, Map, ExprNode, SearchControls)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$, $Date$
@@ -87,7 +87,7 @@
     }
 
 
-    protected Object doExecute( BackingStore store ) throws NamingException
+    protected Object doExecute( ContextPartition store ) throws NamingException
     {
         return store.search( getBaseName(), environment, filter, controls );
     }
@@ -24,11 +24,11 @@
 
 /**
- * Represents an {@link Invocation} on {@link BackingStore#search(Name, Map, ExprNode, SearchControls)}.
+ * Represents an {@link Invocation} on {@link ContextPartition#search(Name, Map, ExprNode, SearchControls)}.
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/SubtreeInvocation.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/SubtreeInvocation.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/SubtreeInvocation.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/invocation/SubtreeInvocation.java Mon Jun 20 06:33:00 2005
@@ -20,10 +20,10 @@
 
 import javax.naming.Name;
 
-import org.apache.ldap.server.partition.BackingStore;
+import org.apache.ldap.server.partition.ContextPartition;
 
 /**
  * Represents a method invocation on a DIT in {@link BackingStore}s.
  * <p/>
  * This class is abstract, and developers should extend this class to
  * represent the actual method invocations.
@@ -20,10 +20,10 @@
 
 /**
- * Represents a method invocation on a DIT in {@link BackingStore}s.
+ * Represents a method invocation on a DIT in {@link ContextPartition}s.
  * <p/>
  * This class is abstract, and developers should extend this class to

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/DefaultContextFactoryConfiguration.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/jndi/DefaultContextFactoryConfiguration.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================
--- directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/PartitionNexus.java (original)
+++ directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/PartitionNexus.java Mon Jun 20 06:33:00 2005
@@ -25,15 +25,15 @@
 
 
 /**
  * The PartitionNexus is a special type of BackingStore designed to route
  * BackingStore operations to ContextPartitions based on namespace to respective
  * ContextPartitions attached to the nexus at the appropriate naming contexts.
  * These naming contexts are also the suffixes of ContextPartitions.  All
  * entries within a ContextPartition have the same suffix.  The PartitionNexus
  * is a singleton where as ContextPartitions can be many hanging off of
  * different contexts on the nexus.
  *
  * The PartitionNexus routes or proxies BackingStore calls to the appropriate
  * PartitionContext implementation.  It also provides some extended operations
  * for the entire backend apparatus like listing the various naming contexts or
  * partition suffixes within the system.  The nexus is also responsibe for
@@ -43,7 +43,7 @@
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  * @version $Rev$
  */
-public interface PartitionNexus extends BackingStore
+public interface PartitionNexus extends ContextPartition
 {
     /**
      * Gets the LdapContext associated with the calling thread.
@@ -25,15 +25,15 @@
 
 /**
- * The PartitionNexus is a special type of BackingStore designed to route
- * BackingStore operations to ContextPartitions based on namespace to respective
+ * The PartitionNexus is a special type of ContextPartition designed to route
+ * ContextPartition operations to ContextPartitions based on namespace to respective
  * ContextPartitions attached to the nexus at the appropriate naming contexts.
  * These naming contexts are also the suffixes of ContextPartitions.  All
@@ -25,15 +25,15 @@
  * different contexts on the nexus.
  *
- * The PartitionNexus routes or proxies BackingStore calls to the appropriate
+ * The PartitionNexus routes or proxies ContextPartition calls to the appropriate
  * PartitionContext implementation.  It also provides some extended operations
  * for the entire backend apparatus like listing the various naming contexts or

Modified: directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/RootNexus.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/branches/db_refactor/core/src/main/java/org/apache/ldap/server/partition/RootNexus.java?rev=191462&r1=191461&r2=191462&view=diff
==============================================================================